@@ -38,6 +38,11 @@ def getMacAddress():
     return mac
 
 def populate_results(url, index, results, resultsWindow, append):
+    try:
+        resultsWindow.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+        app.processEvents()
+    except:
+        pass
     del results[:]
     resultsWindow.listWidgetResults.clear()
     safeurl = urllib.quote(url, safe="%/:=&?~#+!$,;'@()*[]")
@@ -74,6 +79,10 @@ def populate_results(url, index, results, resultsWindow, append):
     resultsWindow.index = index
     resultsWindow.listWidgetResults.setFocus()
     resultsWindow.updatePushButtons(index)
+    try:
+        resultsWindow.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+    except:
+        pass
 
 class SearchWindow(QMainWindow, Ui_SearchWindow):
 
@@ -92,6 +101,11 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
         self.lineEditSearch.setFocus()
 
     def doSearch(self, url, buttonText, presetAction, windowTitle):
+        try:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+            app.processEvents()
+        except:
+            pass
         self.resultsWindow.history = []
         populate_results(url, 0, self.results, self.resultsWindow, True)
         if len(self.results) == 0:
@@ -101,10 +115,11 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
         self.resultsWindow.setWindowTitle(windowTitle)
         try:
             self.resultsWindow.setAttribute(Qt.WA_Maemo5StackedWindow)
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
         except:
                pass
         self.resultsWindow.show()
-    
+
     def on_pushButtonSearch_released(self):
         url = RADIO_TIME_SEARCH_URL % (self.serial, self.lineEditSearch.text())
         self.doSearch(url, 'Add', 'add', 'Search Results')
@@ -112,7 +127,7 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
     def on_lineEditSearch_returnPressed(self):
         url = RADIO_TIME_SEARCH_URL % (self.serial, self.lineEditSearch.text())
         self.doSearch(url, 'Add', 'add', 'Search Results')
-        
+
     def on_pushButtonPresets_released(self):
         if self.serial == '00:00:00:00:00:00':
             QMessageBox.information(self, self.tr("Preset Status"), self.tr("Unique ID not found. Presets unavailable."))
@@ -173,10 +188,19 @@ class ResultsWindow(QMainWindow, Ui_ResultsWindow):
            if ui.results[self.index].get('type') == "audio":
               split = ui.results[self.index]['URL'].split('?')
               if (len(split) > 1):
+                try:
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+                    app.processEvents()
+                except:
+                    pass
                 url = RADIO_TIME_PRESET_ACTION_URL % (self.presetAction, split[1])
                 #print url
                 dom = minidom.parse(urllib.urlopen(url))
                 result = dom.getElementsByTagName('status')[0].firstChild.data
+                try:
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+                except:
+                    pass
                 if self.presetAction == 'add' and result == '200':
                     QMessageBox.information(self, self.tr("Preset Status"), self.tr("Preset Added Successfully"))
                 elif self.presetAction == 'add' and result != '200':
